Atlas class
Atlas is a Flutter Widget which abstracts the underlying map provider
and exposes a developer-friendly, declarative API for working with a map.
The underlying map provider that will be used must be specified as the
AtlasProvider.instance before the Atlas widget is rendered.
- Inheritance
Constructors
-
Atlas({Key? key, required CameraPosition initialCameraPosition, Set<
Marker> ? markers, Set<Callout> ? callouts, Set<Circle> ? circles, Set<Polygon> ? polygons, Set<Polyline> ? polylines, Set<Cluster> ? clusters, TrackPlayback? trackPlayback, bool? showMyLocation, bool? showMyLocationButton, bool? followMyLocation, MapType? mapType, bool? showTraffic, MapLanguage? mapLanguage, ArgumentCallback<LatLng> ? onTap, ArgumentCallback<Poi> ? onPoiTap, ArgumentCallback<LatLng> ? onLongPress, ArgumentCallback<AtlasController> ? onMapCreated, ArgumentCallback<CameraPosition> ? onCameraPositionChanged, ArgumentCallback<LatLng> ? onLocationChanged, VoidCallback? onPan, DeviceLocation? deviceLocation, String? deviceLocationIconAsset, String? country, bool? setPoliticalViews, double? zoom, double? minZoom, double? maxZoom, ArgumentCallback<Polyline> ? onPolylineTap})
Properties
-
callouts
→ Set<
Callout> ? -
The Set of
Calloutobjects which will be rendered on the map.final -
circles
→ Set<
Circle> ? -
The Set of
Circleobjects which will be rendered on the map.final -
clusters
→ Set<
Cluster> ? -
The Set of
Clusterobjects which will be rendered on the map.final - country → String?
-
Sets the country name.
final
- deviceLocation → DeviceLocation?
-
Sets the device location coordinates with accuracy.
final
- deviceLocationIconAsset → String?
-
Sets the device location icon asset path.
final
- followMyLocation → bool?
-
This option enables the map to update its camera position so that
the user's current location is always shown in the center of the screen
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialCameraPosition → CameraPosition
-
The
CameraPositionwhich the map will initially be focused on.final - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mapLanguage → MapLanguage?
-
Sets the map exhibition language.
final
- mapType → MapType?
-
Sets the underlying map type to be displayed.
final
-
markers
→ Set<
Marker> ? -
The Set of
Markerobjects which will be rendered on the map.final - maxZoom → double?
-
Double To indicate the maximum zoom level
final
- minZoom → double?
-
Double To indicate the minimum zoom level
final
-
onCameraPositionChanged
→ ArgumentCallback<
CameraPosition> ? -
onCameraPositionChangedgets called when the map's camera position is changed. The updatedCameraPositionis passed as an argument.final -
onLocationChanged
→ ArgumentCallback<
LatLng> ? -
onLocationChangedcallback which receives a position when the user movesfinal -
onLongPress
→ ArgumentCallback<
LatLng> ? -
onLongPressgets called when the map is long pressed TheLatLngof the location where the pressed event occurred is passed as an argument.final -
onMapCreated
→ ArgumentCallback<
AtlasController> ? -
onMapCreatedgets called when the map is initialized and provides anAtlasControllerwhich can be used to manipulate the map.final - onPan → VoidCallback?
-
onPangets called when the map is panned by user pan gesture.final -
onPoiTap
→ ArgumentCallback<
Poi> ? -
onPoiTapgets called when a valid point on the map is clicked. When the clicked place is not valid point,onTapgets called. ThePoicontains the name and latitude and longitude of the valid point.final -
onPolylineTap
→ ArgumentCallback<
Polyline> ? -
onPolylineTapgets called when a valid polyline on the map is clicked. When the clicked place is not valid polyline,onTapgets called. ThePolylinecontains the id and a list of valid points.final -
onTap
→ ArgumentCallback<
LatLng> ? -
onTapgets called when the map is tapped. TheLatLngof the location where the pressed event occurred is passed as an argument.final -
polygons
→ Set<
Polygon> ? -
The Set of
Polygonobjects which will be rendered on the map.final -
polylines
→ Set<
Polyline> ? -
The Set of
Polylineobjects which will be rendered on the map.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setPoliticalViews → bool?
-
Bool To indicate if the provider should set the political views
final
- showMyLocation → bool?
-
showMyLocationdetermines whether or not the current device location should be displayed on the map. It will default to false if not specified.final - showMyLocationButton → bool?
-
Enables or disables the my-location button.
final
- showTraffic → bool?
-
Enable real-time traffic information status
final
- trackPlayback → TrackPlayback?
-
TrackPlaybackobjects which will be rendered on the map.final - zoom → double?
-
Double To indicate the zoom level
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited